@@ -1,6 +1,7 @@
 from math import ceil
 from unittest.mock import patch
 
+import requests
 import requests_mock
 from packaging.version import Version as Pep440Version
 
@@ -10,9 +11,9 @@ from django.test import TestCase
 from allianceauth.templatetags.admin_status import (
     status_overview,
     _fetch_list_from_gitlab,
-    _current_notifications, 
-    _current_version_summary, 
-    _fetch_notification_issues_from_gitlab,    
+    _current_notifications,
+    _current_version_summary,
+    _fetch_notification_issues_from_gitlab,
     _latests_versions
 )
 
@@ -58,10 +59,10 @@ class TestStatusOverviewTag(TestCase):
     @patch(MODULE_PATH + '.admin_status.__version__', TEST_VERSION)
     @patch(MODULE_PATH + '.admin_status._fetch_celery_queue_length')
     @patch(MODULE_PATH + '.admin_status._current_version_summary')
-    @patch(MODULE_PATH + '.admin_status._current_notifications')    
+    @patch(MODULE_PATH + '.admin_status._current_notifications')
     def test_status_overview(
-        self, 
-        mock_current_notifications, 
+        self,
+        mock_current_notifications,
         mock_current_version_info,
         mock_fetch_celery_queue_length
     ):
@@ -82,7 +83,7 @@ class TestStatusOverviewTag(TestCase):
         }
         mock_current_version_info.return_value = version_info
         mock_fetch_celery_queue_length.return_value = 3
-                
+
         result = status_overview()
         expected = {
             'notifications': GITHUB_NOTIFICATION_ISSUES[:5],
@@ -111,7 +112,7 @@ class TestNotifications(TestCase):
         url = (
             'https://gitlab.com/api/v4/projects/allianceauth%2Fallianceauth/issues'
             '?labels=announcement'
-        )        
+        )
         requests_mocker.get(url, json=GITHUB_NOTIFICATION_ISSUES)
         # when
         result = _fetch_notification_issues_from_gitlab()
@@ -127,13 +128,13 @@ class TestNotifications(TestCase):
         # then
         self.assertEqual(result['notifications'], GITHUB_NOTIFICATION_ISSUES[:5])
 
-    @requests_mock.mock()    
+    @requests_mock.mock()
     def test_current_notifications_failed(self, requests_mocker):
         # given
         url = (
             'https://gitlab.com/api/v4/projects/allianceauth%2Fallianceauth/issues'
             '?labels=announcement'
-        )        
+        )
         requests_mocker.get(url, status_code=404)
         # when
         result = _current_notifications()
@@ -163,17 +164,13 @@ class TestVersionTags(TestCase):
 
     @patch(MODULE_PATH + '.admin_status.__version__', TEST_VERSION)
     @patch(MODULE_PATH + '.admin_status.cache')
-    def test_current_version_info_normal(self, mock_cache):        
+    def test_current_version_info_normal(self, mock_cache):
         # given
         mock_cache.get_or_set.return_value = GITHUB_TAGS
         # when
         result = _current_version_summary()
         # then
-        self.assertTrue(result['latest_major'])
-        self.assertTrue(result['latest_minor'])
         self.assertTrue(result['latest_patch'])
-        self.assertEqual(result['latest_major_version'], '2.0.0')
-        self.assertEqual(result['latest_minor_version'], '2.4.0')
         self.assertEqual(result['latest_patch_version'], '2.4.5')
         self.assertEqual(result['latest_beta_version'], '2.4.6a1')
 
@@ -184,7 +181,7 @@ class TestVersionTags(TestCase):
         url = (
             'https://gitlab.com/api/v4/projects/allianceauth%2Fallianceauth'
             '/repository/tags'
-        )        
+        )
         requests_mocker.get(url, status_code=500)
         # when
         result = _current_version_summary()
@@ -197,7 +194,7 @@ class TestVersionTags(TestCase):
         url = (
             'https://gitlab.com/api/v4/projects/allianceauth%2Fallianceauth'
             '/repository/tags'
-        )        
+        )
         requests_mocker.get(url, json=GITHUB_TAGS)
         # when
         result = _current_version_summary()
@@ -208,7 +205,7 @@ class TestVersionTags(TestCase):
     @patch(MODULE_PATH + '.admin_status.cache')
     def test_current_version_info_return_no_data(self, mock_cache):
         # given
-        mock_cache.get_or_set.return_value = None                
+        mock_cache.get_or_set.return_value = None
         # when
         result = _current_version_summary()
         # then
@@ -218,43 +215,37 @@ class TestVersionTags(TestCase):
 class TestLatestsVersion(TestCase):
 
     def test_all_version_types_defined(self):
-        
+
         tags = create_tags_list(
             ['2.1.1', '2.1.0', '2.0.0', '2.1.1a1', '1.1.1', '1.1.0', '1.0.0']
         )
-        major, minor, patch, beta = _latests_versions(tags)
-        self.assertEqual(major, Pep440Version('2.0.0'))
-        self.assertEqual(minor, Pep440Version('2.1.0'))
+        patch, beta = _latests_versions(tags)
         self.assertEqual(patch, Pep440Version('2.1.1'))
         self.assertEqual(beta, Pep440Version('2.1.1a1'))
 
     def test_major_and_minor_not_defined_with_zero(self):
-        
+
         tags = create_tags_list(
             ['2.1.2', '2.1.1', '2.0.1', '2.1.1a1', '1.1.1', '1.1.0', '1.0.0']
         )
-        major, minor, patch, beta = _latests_versions(tags)
-        self.assertEqual(major, Pep440Version('2.0.1'))
-        self.assertEqual(minor, Pep440Version('2.1.1'))
+        patch, beta = _latests_versions(tags)
         self.assertEqual(patch, Pep440Version('2.1.2'))
         self.assertEqual(beta, Pep440Version('2.1.1a1'))
-        
+
     def test_can_ignore_invalid_versions(self):
-        
+
         tags = create_tags_list(
             ['2.1.1', '2.1.0', '2.0.0', '2.1.1a1', 'invalid']
         )
-        major, minor, patch, beta = _latests_versions(tags)
-        self.assertEqual(major, Pep440Version('2.0.0'))
-        self.assertEqual(minor, Pep440Version('2.1.0'))
+        patch, beta = _latests_versions(tags)
         self.assertEqual(patch, Pep440Version('2.1.1'))
         self.assertEqual(beta, Pep440Version('2.1.1a1'))
 
 
 class TestFetchListFromGitlab(TestCase):
-   
+
     page_size = 2
-    
+
     def setUp(self):
         self.url = (
             'https://gitlab.com/api/v4/projects/allianceauth%2Fallianceauth'
@@ -266,8 +257,8 @@ class TestFetchListFromGitlab(TestCase):
         page = int(request.qs['page'][0])
         start = (page - 1) * cls.page_size
         end = start + cls.page_size
-        return GITHUB_TAGS[start:end]        
-    
+        return GITHUB_TAGS[start:end]
+
     @requests_mock.mock()
     def test_can_fetch_one_page_with_header(self, requests_mocker):
         headers = {
@@ -279,7 +270,7 @@ class TestFetchListFromGitlab(TestCase):
         self.assertEqual(requests_mocker.call_count, 1)
 
     @requests_mock.mock()
-    def test_can_fetch_one_page_wo_header(self, requests_mocker):        
+    def test_can_fetch_one_page_wo_header(self, requests_mocker):
         requests_mocker.get(self.url, json=GITHUB_TAGS)
         result = _fetch_list_from_gitlab(self.url)
         self.assertEqual(result, GITHUB_TAGS)
@@ -296,7 +287,7 @@ class TestFetchListFromGitlab(TestCase):
         self.assertEqual(requests_mocker.call_count, 1)
 
     @requests_mock.mock()
-    def test_can_fetch_multiple_pages(self, requests_mocker):     
+    def test_can_fetch_multiple_pages(self, requests_mocker):
         total_pages = ceil(len(GITHUB_TAGS) / self.page_size)
         headers = {
             'x-total-pages': str(total_pages)
@@ -307,7 +298,7 @@ class TestFetchListFromGitlab(TestCase):
         self.assertEqual(requests_mocker.call_count, total_pages)
 
     @requests_mock.mock()
-    def test_can_fetch_given_number_of_pages_only(self, requests_mocker):     
+    def test_can_fetch_given_number_of_pages_only(self, requests_mocker):
         total_pages = ceil(len(GITHUB_TAGS) / self.page_size)
         headers = {
             'x-total-pages': str(total_pages)
@@ -317,3 +308,25 @@ class TestFetchListFromGitlab(TestCase):
         result = _fetch_list_from_gitlab(self.url, max_pages=max_pages)
         self.assertEqual(result, GITHUB_TAGS[:4])
         self.assertEqual(requests_mocker.call_count, max_pages)
+
+    @requests_mock.mock()
+    @patch(MODULE_PATH + '.admin_status.logger')
+    def test_should_not_raise_any_exception_from_github_request_but_log_as_warning(
+        self, requests_mocker, mock_logger
+    ):
+        for my_exception in [
+            requests.exceptions.ConnectionError,
+            requests.exceptions.HTTPError,
+            requests.exceptions.URLRequired,
+            requests.exceptions.TooManyRedirects,
+            requests.exceptions.ConnectTimeout,
+            requests.exceptions.Timeout,
+
+        ]:
+            requests_mocker.get(self.url, exc=my_exception)
+            try:
+                result = _fetch_list_from_gitlab(self.url)
+            except Exception as ex:
+                self.fail(f"Unexpected exception raised: {ex}")
+            self.assertTrue(mock_logger.warning.called)
+            self.assertListEqual(result, [])
