@@ -6,11 +6,13 @@ from allianceauth.corputils import urls
 
 class CorpStats(MenuItemHook):
     def __init__(self):
-        MenuItemHook.__init__(self,
-                              _('Corporation Stats'),
-                              'fas fa-share-alt fa-fw',
-                              'corputils:view',
-                              navactive=['corputils:'])
+        MenuItemHook.__init__(
+            self,
+            _('Corporation Stats'),
+            'fas fa-share-alt fa-fw',
+            'corputils:view',
+            navactive=['corputils:']
+        )
 
     def render(self, request):
         if request.user.has_perm('corputils.view_corp_corpstats') or request.user.has_perm(
