@@ -3,7 +3,7 @@ from unittest.mock import Mock, patch
 from django.test import TestCase
 
 from ..models import (
-    EveCharacter, EveCorporationInfo, EveAllianceInfo
+    EveCharacter, EveCorporationInfo, EveAllianceInfo, EveFactionInfo
 )
 from ..providers import Alliance, Corporation, Character
 from ..evelinks import eveimageserver
@@ -126,6 +126,66 @@ class EveCharacterTestCase(TestCase):
 
         self.assertIsNone(character.alliance)
 
+    def test_faction_prop(self):
+        """
+        Test that the correct faction is returned by the alliance property
+        """
+        character = EveCharacter.objects.create(
+            character_id=1234,
+            character_name='character.name',
+            corporation_id=2345,
+            corporation_name='character.corp.name',
+            corporation_ticker='cc1',
+            alliance_id=3456,
+            alliance_name='character.alliance.name',
+            faction_id=1337,
+            faction_name='character.faction.name'
+        )
+
+        expected = EveFactionInfo.objects.create(faction_id=1337, faction_name='faction.name')
+        incorrect = EveFactionInfo.objects.create(faction_id=8008, faction_name='faction.badname')
+
+        self.assertEqual(character.faction, expected)
+        self.assertNotEqual(character.faction, incorrect)
+
+    def test_faction_prop_exception(self):
+        """
+        Check that an exception is raised when the expected
+        object is not in the database
+        """
+        character = EveCharacter.objects.create(
+            character_id=1234,
+            character_name='character.name',
+            corporation_id=2345,
+            corporation_name='character.corp.name',
+            corporation_ticker='cc1',
+            alliance_id=3456,
+            alliance_name='character.alliance.name',
+            faction_id=1337,
+            faction_name='character.faction.name'
+        )
+
+        with self.assertRaises(EveFactionInfo.DoesNotExist):
+            character.faction
+
+    def test_faction_prop_none(self):
+        """
+        Check that None is returned when the character has no alliance
+        """
+        character = EveCharacter.objects.create(
+            character_id=1234,
+            character_name='character.name',
+            corporation_id=2345,
+            corporation_name='character.corp.name',
+            corporation_ticker='cc1',
+            alliance_id=None,
+            alliance_name=None,
+            faction_id=None,
+            faction_name=None,
+        )
+
+        self.assertIsNone(character.faction)
+
     @patch('allianceauth.eveonline.providers.provider')
     def test_update_character(self, mock_provider):
         mock_provider.get_corp.return_value = Corporation(
@@ -133,9 +193,9 @@ class EveCharacterTestCase(TestCase):
             name='Dummy Corp 2',
             ticker='DC2',
             ceo_id=1001,
-            members=34,            
+            members=34,
         )
-        
+
         my_character = EveCharacter.objects.create(
             character_id=1001,
             character_name='Bruce Wayne',
@@ -144,13 +204,17 @@ class EveCharacterTestCase(TestCase):
             corporation_ticker='DC1',
             alliance_id=3001,
             alliance_name='Dummy Alliance 1',
-        )        
+            faction_id=1337,
+            faction_name='Dummy Faction 1',
+        )
         my_updated_character = Character(
             name='Bruce X. Wayne',
-            corp_id=2002
+            corp_id=2002,
+            faction_id=None,
         )
         my_character.update_character(my_updated_character)
         self.assertEqual(my_character.character_name, 'Bruce X. Wayne')
+        self.assertFalse(my_character.faction_id)
 
         # todo: add test cases not yet covered, e.g. with alliance
 
@@ -169,8 +233,8 @@ class EveCharacterTestCase(TestCase):
             character_id=42,
             character_name='character.name',
             corporation_id=123,
-            corporation_name='corporation.name',            
-            corporation_ticker='ABC',            
+            corporation_name='corporation.name',
+            corporation_ticker='ABC',
         )
         self.assertEqual(
             x.portrait_url(),
@@ -179,7 +243,7 @@ class EveCharacterTestCase(TestCase):
         self.assertEqual(
             x.portrait_url(64),
             eveimageserver._eve_entity_image_url('character', 42, size=64)
-        )       
+        )
         self.assertEqual(
             x.portrait_url_32,
             eveimageserver._eve_entity_image_url('character', 42, size=32)
@@ -202,8 +266,8 @@ class EveCharacterTestCase(TestCase):
             character_id=42,
             character_name='character.name',
             corporation_id=123,
-            corporation_name='corporation.name',            
-            corporation_ticker='ABC',            
+            corporation_name='corporation.name',
+            corporation_ticker='ABC',
         )
         self.assertEqual(
             x.corporation_logo_url(),
@@ -235,9 +299,9 @@ class EveCharacterTestCase(TestCase):
             character_id=42,
             character_name='character.name',
             corporation_id=123,
-            corporation_name='corporation.name',            
-            corporation_ticker='ABC',            
-        )        
+            corporation_name='corporation.name',
+            corporation_ticker='ABC',
+        )
         self.assertEqual(
             x.alliance_logo_url(),
             ''
@@ -286,7 +350,7 @@ class EveCharacterTestCase(TestCase):
 
 
 class EveAllianceTestCase(TestCase):
-            
+
     def test_str(self):
         my_alliance = EveAllianceInfo(
             alliance_id=3001,
@@ -295,12 +359,12 @@ class EveAllianceTestCase(TestCase):
             executor_corp_id=2001
         )
         self.assertEqual(str(my_alliance), 'Dummy Alliance 1')
-    
+
     @patch(
         'allianceauth.eveonline.models.EveCorporationInfo.objects.create_corporation'
     )
     def test_populate_alliance(self, mock_create_corporation):
-        
+
         def create_corp(corp_id):
             if corp_id == 2002:
                 EveCorporationInfo.objects.create(
@@ -311,23 +375,23 @@ class EveAllianceTestCase(TestCase):
                 )
             else:
                 raise ValueError()
-        
+
         mock_EveAllianceProviderManager = Mock()
         mock_EveAllianceProviderManager.get_alliance.return_value = \
             Alliance(
-                id=3001, 
+                id=3001,
                 name='Dummy Alliance 1',
                 corp_ids=[2001, 2002]
             )
         mock_create_corporation.side_effect = create_corp
-        
+
         EveCorporationInfo.objects.create(
             corporation_id=2001,
             corporation_name='Dummy Corporation 1',
             corporation_ticker='DC1',
             member_count=42,
         )
-                
+
         my_alliance = EveAllianceInfo(
             alliance_id=3001,
             alliance_name='Dummy Alliance 1',
@@ -336,13 +400,13 @@ class EveAllianceTestCase(TestCase):
         )
         my_alliance.provider = mock_EveAllianceProviderManager
         my_alliance.save()
-        my_alliance.populate_alliance()        
+        my_alliance.populate_alliance()
 
         for corporation in EveCorporationInfo.objects\
             .filter(corporation_id__in=[2001, 2002]
         ):
             self.assertEqual(corporation.alliance, my_alliance)
-        
+
     def test_update_alliance_with_object(self):
         my_alliance = EveAllianceInfo.objects.create(
             alliance_id=3001,
@@ -351,9 +415,9 @@ class EveAllianceTestCase(TestCase):
             executor_corp_id=2001
         )
         updated_alliance = Alliance(
-            id=3002, 
+            id=3002,
             name='Dummy Alliance 2',
-            corp_ids=[2004],                
+            corp_ids=[2004],
             executor_corp_id=2004
         )
         my_alliance.update_alliance(updated_alliance)
@@ -367,7 +431,7 @@ class EveAllianceTestCase(TestCase):
         mock_EveAllianceProviderManager = Mock()
         mock_EveAllianceProviderManager.get_alliance.return_value = \
             Alliance(
-                id=3002, 
+                id=3002,
                 name='Dummy Alliance 2',
                 corp_ids=[2004],
                 executor_corp_id=2004
@@ -381,15 +445,15 @@ class EveAllianceTestCase(TestCase):
         )
         my_alliance.provider = mock_EveAllianceProviderManager
         my_alliance.save()
-        Alliance(                
+        Alliance(
             name='Dummy Alliance 2',
-            corp_ids=[2004],                
+            corp_ids=[2004],
             executor_corp_id=2004
         )
         my_alliance.update_alliance()
         my_alliance.refresh_from_db()
         self.assertEqual(int(my_alliance.executor_corp_id), 2004)
-        
+
         # potential bug
         # update_alliance() is only updateting executor_corp_id nothing else ???
 
@@ -417,7 +481,7 @@ class EveAllianceTestCase(TestCase):
         self.assertEqual(
             x.logo_url(64),
             'https://images.evetech.net/alliances/42/logo?size=64'
-        )        
+        )
         self.assertEqual(
             x.logo_url_32,
             'https://images.evetech.net/alliances/42/logo?size=32'
@@ -434,10 +498,10 @@ class EveAllianceTestCase(TestCase):
             x.logo_url_256,
             'https://images.evetech.net/alliances/42/logo?size=256'
         )
-        
+
 
 class EveCorporationTestCase(TestCase):
-    
+
     def setUp(self):
         my_alliance = EveAllianceInfo.objects.create(
             alliance_id=3001,
@@ -451,9 +515,9 @@ class EveCorporationTestCase(TestCase):
             corporation_ticker='DC1',
             member_count=42,
             alliance=my_alliance
-        )        
+        )
 
-    def test_str(self):        
+    def test_str(self):
         self.assertEqual(str(self.my_corp), 'Dummy Corporation 1')
 
     def test_update_corporation_from_object_w_alliance(self):
@@ -465,15 +529,15 @@ class EveCorporationTestCase(TestCase):
 
         # potential bug
         # update_corporation updates member_count only
-    
+
     def test_update_corporation_no_object_w_alliance(self):
         mock_provider = Mock()
         mock_provider.get_corporation.return_value = Corporation(members=87)
         self.my_corp.provider = mock_provider
-        
+
         self.my_corp.update_corporation()
         self.assertEqual(self.my_corp.member_count, 87)
-            
+
     def test_update_corporation_from_object_wo_alliance(self):
         my_corp2 = EveCorporationInfo(
             corporation_id=2011,
@@ -498,7 +562,7 @@ class EveCorporationTestCase(TestCase):
             eveimageserver._eve_entity_image_url('corporation', 42, 256)
         )
 
-    def test_logo_url(self):        
+    def test_logo_url(self):
         self.assertEqual(
             self.my_corp.logo_url(),
             'https://images.evetech.net/corporations/2001/logo?size=32'
