@@ -8,17 +8,18 @@ from django.test import TestCase
 
 from . import set_logger
 from ..providers import (
-    ObjectNotFound, 
-    Entity, 
-    Character, 
-    Corporation, 
-    Alliance, 
-    ItemType, 
-    EveProvider, 
+    ObjectNotFound,
+    Entity,
+    AllianceMixin,
+    FactionMixin,
+    Character,
+    Corporation,
+    Alliance,
+    ItemType,
+    EveProvider,
     EveSwaggerProvider
 )
 
-
 MODULE_PATH = 'allianceauth.eveonline.providers'
 SWAGGER_OLD_SPEC_PATH = os.path.join(os.path.dirname(
     os.path.abspath(__file__)), 'swagger_old.json'
@@ -80,6 +81,72 @@ class TestEntity(TestCase):
         # bug: missing _neq_ in Equity to compliment _eq_
 
 
+class TestAllianceMixin(TestCase):
+    @patch(MODULE_PATH + '.EveSwaggerProvider.get_alliance')
+    def test_alliance_defined(self, mock_provider_get_alliance):
+        my_alliance = Alliance(
+            id=3001,
+            name='Dummy Alliance',
+            ticker='Dummy',
+            corp_ids=[2001, 2002, 2003],
+            executor_corp_id=2001
+        )
+        mock_provider_get_alliance.return_value = my_alliance
+
+        x = AllianceMixin(alliance_id=3001)
+        self.assertEqual(
+            x.alliance,
+            my_alliance
+        )
+        self.assertEqual(
+            x.alliance,
+            my_alliance
+        )
+        # should fetch alliance once only
+        self.assertEqual(mock_provider_get_alliance.call_count, 1)
+
+    @patch(MODULE_PATH + '.EveSwaggerProvider.get_alliance')
+    def test_alliance_not_defined(self, mock_provider_get_alliance):
+        mock_provider_get_alliance.return_value = None
+
+        x = AllianceMixin()
+        self.assertEqual(
+            x.alliance,
+            Entity(None, None)
+        )
+        self.assertEqual(mock_provider_get_alliance.call_count, 0)
+
+
+class TestFactionMixin(TestCase):
+    @patch(MODULE_PATH + '.EveSwaggerProvider.get_faction')
+    def test_faction_defined(self, mock_provider_get_faction):
+        my_faction = Entity(id=1337, name='Permabanned')
+        mock_provider_get_faction.return_value = my_faction
+
+        x = FactionMixin(faction_id=3001)
+        self.assertEqual(
+            x.faction,
+            my_faction
+        )
+        self.assertEqual(
+            x.faction,
+            my_faction
+        )
+        # should fetch alliance once only
+        self.assertEqual(mock_provider_get_faction.call_count, 1)
+
+    @patch(MODULE_PATH + '.EveSwaggerProvider.get_alliance')
+    def test_faction_not_defined(self, mock_provider_get_faction):
+        mock_provider_get_faction.return_value = None
+
+        x = FactionMixin()
+        self.assertEqual(
+            x.faction,
+            Entity(None, None)
+        )
+        self.assertEqual(mock_provider_get_faction.call_count, 0)
+
+
 class TestCorporation(TestCase):
 
     @patch(MODULE_PATH + '.EveSwaggerProvider.get_alliance')
@@ -92,12 +159,12 @@ class TestCorporation(TestCase):
             executor_corp_id=2001
         )
         mock_provider_get_alliance.return_value = my_alliance
-        
+
         x = Corporation(alliance_id=3001)
         self.assertEqual(
             x.alliance,
             my_alliance
-        )        
+        )
         self.assertEqual(
             x.alliance,
             my_alliance
@@ -106,25 +173,26 @@ class TestCorporation(TestCase):
         self.assertEqual(mock_provider_get_alliance.call_count, 1)
 
     @patch(MODULE_PATH + '.EveSwaggerProvider.get_alliance')
-    def test_alliance_not_defined(self, mock_provider_get_alliance):        
+    def test_alliance_not_defined(self, mock_provider_get_alliance):
         mock_provider_get_alliance.return_value = None
-        
+
         x = Corporation()
         self.assertEqual(
             x.alliance,
             Entity(None, None)
         )
-        
+        self.assertEqual(mock_provider_get_alliance.call_count, 0)
+
     @patch(MODULE_PATH + '.EveSwaggerProvider.get_character')
-    def test_ceo(self, mock_provider_get_character):        
+    def test_ceo(self, mock_provider_get_character):
         my_ceo = Character(
             id=1001,
             name='Bruce Wayne',
             corp_id=2001,
             alliance_id=3001
-        )        
+        )
         mock_provider_get_character.return_value = my_ceo
-                
+
         # fetch from provider if not defined
         x = Corporation()
         self.assertEqual(
@@ -142,7 +210,27 @@ class TestCorporation(TestCase):
 
         # bug in ceo(): will try to fetch character even if ceo_id is None
 
-    
+    @patch(MODULE_PATH + '.EveSwaggerProvider.get_faction')
+    def test_faction_defined(self, mock_provider_get_faction):
+        my_faction = Entity(id=1337, name='Permabanned')
+        mock_provider_get_faction.return_value = my_faction
+
+        # fetch from provider if not defined
+        x = Corporation(faction_id=1337)
+        self.assertEqual(x.faction, my_faction)
+
+        # return existing if defined
+        mock_provider_get_faction.return_value = None
+        self.assertEqual(x.faction, my_faction)
+        self.assertEqual(mock_provider_get_faction.call_count, 1)
+
+    @patch(MODULE_PATH + '.EveSwaggerProvider.get_faction')
+    def test_faction_undefined(self, mock_provider_get_faction):
+        x = Corporation()
+        self.assertEqual(x.faction, Entity())
+        self.assertEqual(mock_provider_get_faction.call_count, 0)
+
+
 class TestAlliance(TestCase):
 
     def setUp(self):
@@ -151,52 +239,53 @@ class TestAlliance(TestCase):
             name='Dummy Alliance',
             ticker='Dummy',
             corp_ids=[2001, 2002, 2003],
-            executor_corp_id=2001
+            executor_corp_id=2001,
+            faction_id=1337
         )
 
     @staticmethod
-    def _get_corp(corp_id):        
+    def _get_corp(corp_id):
         corps = {
             2001: Corporation(
                 id=2001,
                 name='Dummy Corp 1',
-                alliance_id=3001            
+                alliance_id=3001
             ),
             2002: Corporation(
                 id=2002,
                 name='Dummy Corp 2',
-                alliance_id=3001            
+                alliance_id=3001
             ),
             2003: Corporation(
                 id=2003,
                 name='Dummy Corp 3',
-                alliance_id=3001            
+                alliance_id=3001
             ),
         }
-        
-        if corp_id:                
+
+        if corp_id:
             return corps[int(corp_id)]
 
     @patch(MODULE_PATH + '.EveSwaggerProvider.get_corp')
-    def test_corp(self, mock_provider_get_corp):                
+    def test_corp(self, mock_provider_get_corp):
         mock_provider_get_corp.side_effect = TestAlliance._get_corp
-        
-        # should fetch corp if not in the object                
+
+        # should fetch corp if not in the object
         self.assertEqual(
             self.my_alliance.corp(2001),
             TestAlliance._get_corp(2001)
         )
-        # should fetch corp if not in the object                
+        # should fetch corp if not in the object
         self.assertEqual(
             self.my_alliance.corp(2002),
             TestAlliance._get_corp(2002)
         )
-        # should return from the object if its there        
+        # should return from the object if its there
         self.assertEqual(
             self.my_alliance.corp(2001),
             TestAlliance._get_corp(2001)
         )
-        # should return from the object if its there        
+        # should return from the object if its there
         self.assertEqual(
             self.my_alliance.corp(2002),
             TestAlliance._get_corp(2002)
@@ -220,7 +309,7 @@ class TestAlliance(TestCase):
     @patch(MODULE_PATH + '.EveSwaggerProvider.get_corp')
     def test_executor_corp(self, mock_provider_get_corp):
         mock_provider_get_corp.side_effect = TestAlliance._get_corp
-        
+
         self.assertEqual(
             self.my_alliance.executor_corp,
             TestAlliance._get_corp(2001),
@@ -232,6 +321,25 @@ class TestAlliance(TestCase):
             Entity(None, None),
         )
 
+    @patch(MODULE_PATH + '.EveSwaggerProvider.get_faction')
+    def test_faction_defined(self, mock_provider_get_faction):
+        my_faction = Entity(id=1337, name='Permabanned')
+        mock_provider_get_faction.return_value = my_faction
+
+        # fetch from provider if not defined
+        self.assertEqual(self.my_alliance.faction, my_faction)
+
+        # return existing if defined
+        mock_provider_get_faction.return_value = None
+        self.assertEqual(self.my_alliance.faction, my_faction)
+        self.assertEqual(mock_provider_get_faction.call_count, 1)
+
+    @patch(MODULE_PATH + '.EveSwaggerProvider.get_faction')
+    def test_faction_undefined(self, mock_provider_get_faction):
+        self.my_alliance.faction_id = None
+        self.assertEqual(self.my_alliance.faction, Entity())
+        self.assertEqual(mock_provider_get_faction.call_count, 0)
+
 
 class TestCharacter(TestCase):
 
@@ -240,7 +348,8 @@ class TestCharacter(TestCase):
             id=1001,
             name='Bruce Wayne',
             corp_id=2001,
-            alliance_id=3001
+            alliance_id=3001,
+            faction_id=1337,
         )
 
     @patch(MODULE_PATH + '.EveSwaggerProvider.get_corp')
@@ -248,7 +357,7 @@ class TestCharacter(TestCase):
         my_corp = Corporation(
             id=2001,
             name='Dummy Corp 1'
-        )        
+        )
         mock_provider_get_corp.return_value = my_corp
 
         self.assertEqual(self.my_character.corp, my_corp)
@@ -256,11 +365,11 @@ class TestCharacter(TestCase):
 
         # should call the provider one time only
         self.assertEqual(mock_provider_get_corp.call_count, 1)
-    
+
     @patch(MODULE_PATH + '.EveSwaggerProvider.get_alliance')
     @patch(MODULE_PATH + '.EveSwaggerProvider.get_corp')
     def test_alliance_has_one(
-        self, 
+        self,
         mock_provider_get_corp,
         mock_provider_get_alliance,
     ):
@@ -268,26 +377,46 @@ class TestCharacter(TestCase):
             id=2001,
             name='Dummy Corp 1',
             alliance_id=3001
-        )        
+        )
         mock_provider_get_corp.return_value = my_corp
         my_alliance = Alliance(
             id=3001,
             name='Dummy Alliance 1',
             executor_corp_id=2001,
             corp_ids=[2001, 2002]
-        )        
+        )
         mock_provider_get_alliance.return_value = my_alliance
 
         self.assertEqual(self.my_character.alliance, my_alliance)
         self.assertEqual(self.my_character.alliance, my_alliance)
 
         # should call the provider one time only
-        self.assertEqual(mock_provider_get_corp.call_count, 1)
         self.assertEqual(mock_provider_get_alliance.call_count, 1)
 
-    def test_alliance_has_none(self):
+    @patch(MODULE_PATH + '.EveSwaggerProvider.get_alliance')
+    def test_alliance_has_none(self, mock_provider_get_alliance):
         self.my_character.alliance_id = None
         self.assertEqual(self.my_character.alliance, Entity(None, None))
+        self.assertEqual(mock_provider_get_alliance.call_count, 0)
+
+    @patch(MODULE_PATH + '.EveSwaggerProvider.get_faction')
+    def test_faction_defined(self, mock_provider_get_faction):
+        my_faction = Entity(id=1337, name='Permabanned')
+        mock_provider_get_faction.return_value = my_faction
+
+        # fetch from provider if not defined
+        self.assertEqual(self.my_character.faction, my_faction)
+
+        # return existing if defined
+        mock_provider_get_faction.return_value = None
+        self.assertEqual(self.my_character.faction, my_faction)
+        self.assertEqual(mock_provider_get_faction.call_count, 1)
+
+    @patch(MODULE_PATH + '.EveSwaggerProvider.get_faction')
+    def test_faction_undefined(self, mock_provider_get_faction):
+        self.my_character.faction_id = None
+        self.assertEqual(self.my_character.faction, Entity())
+        self.assertEqual(mock_provider_get_faction.call_count, 0)
 
 
 class TestItemType(TestCase):
@@ -301,7 +430,7 @@ class TestEveProvider(TestCase):
 
     def setUp(self):
         self.my_provider = EveProvider()
-    
+
     def test_get_alliance(self):
         with self.assertRaises(NotImplementedError):
             self.my_provider.get_alliance(3001)
@@ -315,7 +444,7 @@ class TestEveProvider(TestCase):
             self.my_provider.get_character(1001)
 
     # bug: should be calling NotImplementedError() not NotImplemented
-    """    
+    """
     def test_get_itemtype(self):
         with self.assertRaises(NotImplementedError):
             self.my_provider.get_itemtype(4001)
@@ -323,7 +452,7 @@ class TestEveProvider(TestCase):
 
 
 class TestEveSwaggerProvider(TestCase):
-    
+
     @staticmethod
     def esi_get_alliances_alliance_id(alliance_id):
         alliances = {
@@ -404,11 +533,11 @@ class TestEveSwaggerProvider(TestCase):
     @staticmethod
     def esi_post_characters_affiliation(characters):
         character_data = {
-            1001: {                
+            1001: {
                 'corporation_id': 2001,
                 'alliance_id': 3001
             },
-            1002: {                
+            1002: {
                 'corporation_id': 2101
             }
         }
@@ -424,7 +553,7 @@ class TestEveSwaggerProvider(TestCase):
             return mock_result
         else:
             raise TypeError()
-    
+
     @staticmethod
     def esi_get_universe_types_type_id(type_id):
         types = {
@@ -443,21 +572,21 @@ class TestEveSwaggerProvider(TestCase):
             raise HTTPNotFound(Mock())
 
     @patch(MODULE_PATH + '.esi_client_factory')
-    def test_str(self, mock_esi_client_factory):        
+    def test_str(self, mock_esi_client_factory):
         my_provider = EveSwaggerProvider()
         self.assertEqual(str(my_provider), 'esi')
 
     @patch(MODULE_PATH + '.esi_client_factory')
     def test_get_alliance(self, mock_esi_client_factory):
-        mock_esi_client_factory.return_value\
+        mock_esi_client_factory.return_value \
             .Alliance.get_alliances_alliance_id \
             = TestEveSwaggerProvider.esi_get_alliances_alliance_id
-        mock_esi_client_factory.return_value\
+        mock_esi_client_factory.return_value \
             .Alliance.get_alliances_alliance_id_corporations \
             = TestEveSwaggerProvider.esi_get_alliances_alliance_id_corporations
 
         my_provider = EveSwaggerProvider()
-        
+
         # fully defined alliance
         my_alliance = my_provider.get_alliance(3001)
         self.assertEqual(my_alliance.id, 3001)
@@ -477,7 +606,7 @@ class TestEveSwaggerProvider(TestCase):
 
     @patch(MODULE_PATH + '.esi_client_factory')
     def test_get_corp(self, mock_esi_client_factory):
-        mock_esi_client_factory.return_value\
+        mock_esi_client_factory.return_value \
             .Corporation.get_corporations_corporation_id \
             = TestEveSwaggerProvider.esi_get_corporations_corporation_id
 
@@ -494,19 +623,19 @@ class TestEveSwaggerProvider(TestCase):
 
         # corporation wo/ alliance
         my_corp = my_provider.get_corp(2002)
-        self.assertEqual(my_corp.id, 2002)        
+        self.assertEqual(my_corp.id, 2002)
         self.assertEqual(my_corp.alliance_id, None)
 
         # corporation not found
         with self.assertRaises(ObjectNotFound):
             my_provider.get_corp(2999)
-        
+
     @patch(MODULE_PATH + '.esi_client_factory')
     def test_get_character(self, mock_esi_client_factory):
-        mock_esi_client_factory.return_value\
+        mock_esi_client_factory.return_value \
             .Character.get_characters_character_id \
             = TestEveSwaggerProvider.esi_get_characters_character_id
-        mock_esi_client_factory.return_value\
+        mock_esi_client_factory.return_value \
             .Character.post_characters_affiliation \
             = TestEveSwaggerProvider.esi_post_characters_affiliation
 
@@ -530,7 +659,7 @@ class TestEveSwaggerProvider(TestCase):
 
     @patch(MODULE_PATH + '.esi_client_factory')
     def test_get_itemtype(self, mock_esi_client_factory):
-        mock_esi_client_factory.return_value\
+        mock_esi_client_factory.return_value \
             .Universe.get_universe_types_type_id \
             = TestEveSwaggerProvider.esi_get_universe_types_type_id
 
@@ -540,7 +669,7 @@ class TestEveSwaggerProvider(TestCase):
         my_type = my_provider.get_itemtype(4001)
         self.assertEqual(my_type.id, 4001)
         self.assertEqual(my_type.name, 'Dummy Type 1')
-        
+
         # type not found
         with self.assertRaises(ObjectNotFound):
             my_provider.get_itemtype(4999)
@@ -551,16 +680,16 @@ class TestEveSwaggerProvider(TestCase):
         my_provider = EveSwaggerProvider()
         self.assertTrue(mock_esi_client_factory.called)
         self.assertIsNotNone(my_provider._client)
-    
+
     @patch(MODULE_PATH + '.SWAGGER_SPEC_PATH', SWAGGER_OLD_SPEC_PATH)
     @patch(MODULE_PATH + '.settings.DEBUG', False)
     @patch('socket.socket')
     def test_create_client_on_normal_startup_w_old_swagger_spec(
-        self, mock_socket
+            self, mock_socket
     ):
         mock_socket.side_effect = Exception('Network blocked for testing')
-        my_provider = EveSwaggerProvider()        
-        self.assertIsNone(my_provider._client)    
+        my_provider = EveSwaggerProvider()
+        self.assertIsNone(my_provider._client)
 
     @patch(MODULE_PATH + '.settings.DEBUG', True)
     @patch(MODULE_PATH + '.esi_client_factory')
@@ -572,7 +701,7 @@ class TestEveSwaggerProvider(TestCase):
     @patch(MODULE_PATH + '.settings.DEBUG', False)
     @patch(MODULE_PATH + '.esi_client_factory')
     def test_dont_create_client_if_client_creation_fails_on_normal_startup(
-        self, mock_esi_client_factory
+            self, mock_esi_client_factory
     ):
         mock_esi_client_factory.side_effect = RefResolutionError(cause='Test')
         my_provider = EveSwaggerProvider()
@@ -582,7 +711,7 @@ class TestEveSwaggerProvider(TestCase):
     @patch(MODULE_PATH + '.settings.DEBUG', True)
     @patch(MODULE_PATH + '.esi_client_factory')
     def test_client_loads_on_demand(
-        self, mock_esi_client_factory
+            self, mock_esi_client_factory
     ):
         mock_esi_client_factory.return_value = 'my_client'
         my_provider = EveSwaggerProvider()
@@ -597,7 +726,7 @@ class TestEveSwaggerProvider(TestCase):
     def test_user_agent_header(self):
         my_provider = EveSwaggerProvider()
         my_client = my_provider.client
-        operation = my_client.Status.get_status()
+        operation = my_client.Universe.get_universe_factions()
         self.assertEqual(
             operation.future.request.headers['User-Agent'], 'allianceauth v1.0.0'
         )
