@@ -5,3 +5,6 @@ class GroupManagementConfig(AppConfig):
     name = 'allianceauth.groupmanagement'
     label = 'groupmanagement'
     verbose_name = 'Group Management'
+
+    def ready(self):
+        from . import signals  # noqa: F401
