@@ -5,16 +5,16 @@ All rights reserved.
 Redistribution and use in source and binary forms, with or without modification,
 are permitted provided that the following conditions are met:
 
-    1. Redistributions of source code must retain the above copyright notice,
-       this list of conditions and the following disclaimer.
+    1.  Redistributions of source code must retain the above copyright notice,
+        this list of conditions and the following disclaimer.
 
-    2. Redistributions in binary form must reproduce the above copyright
-       notice, this list of conditions and the following disclaimer in the
-       documentation and/or other materials provided with the distribution.
+    2.  Redistributions in binary form must reproduce the above copyright
+        notice, this list of conditions and the following disclaimer in the
+        documentation and/or other materials provided with the distribution.
 
-    3. Neither the name of Torchbox nor the names of its contributors may be used
-       to endorse or promote products derived from this software without
-       specific prior written permission.
+    3.  Neither the name of Torchbox nor the names of its contributors may be used
+        to endorse or promote products derived from this software without
+        specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
@@ -67,7 +67,7 @@ def register(name, fn=None):
             logger.debug("Creating new hook %s" % name)
             _hooks[name] = []
 
-        logger.debug('Registering hook %s for function %s' % (name, fn))
+        logger.debug(f'Registering hook {name} for function {fn}')
         _hooks[name].append(func)
 
     if fn is None:
@@ -98,7 +98,7 @@ def get_app_submodules(module_name):
     """
     for name, module in get_app_modules():
         if module_has_submodule(module, module_name):
-            yield name, import_module('{0}.{1}'.format(name, module_name))
+            yield name, import_module(f'{name}.{module_name}')
 
 
 def register_all_hooks():
@@ -122,4 +122,3 @@ def get_hooks(name):
     """
     register_all_hooks()
     return _hooks.get(name, [])
-
