@@ -9,17 +9,18 @@ from .models import Application
 
 class ApplicationsMenu(MenuItemHook):
     def __init__(self):
-        MenuItemHook.__init__(self,
-                              _('Applications'),
-                              'far fa-file fa-fw',
-                              'hrapplications:index',
-                              navactive=['hrapplications:'])
+        MenuItemHook.__init__(
+            self,
+            _('Applications'),
+            'far fa-file fa-fw',
+            'hrapplications:index',
+            navactive=['hrapplications:'])
 
-    def render(self, request):        
+    def render(self, request):
         app_count = Application.objects.pending_requests_count_for_user(request.user)
         self.count = app_count if app_count and app_count > 0 else None
         return MenuItemHook.render(self, request)
-    
+
 
 @hooks.register('menu_item_hook')
 def register_menu():
