@@ -18,15 +18,15 @@ class TestQuerySet(TestCase):
     def setUpTestData(cls):
         cls.user_1 = AuthUtils.create_user('Peter Parker')
         cls.user_2 = AuthUtils.create_user('Clark Kent')
-        
+
     @patch(MODULE_PATH + '.Notification.objects.invalidate_user_notification_cache')
     def test_update_will_invalidate_cache(
         self, mock_invalidate_user_notification_cache
     ):
         Notification.objects.notify_user(self.user_1, 'dummy_1')
-        Notification.objects.notify_user(self.user_2, 'dummy_2')        
-        Notification.objects.update(viewed=True)    
-        self.assertEquals(mock_invalidate_user_notification_cache.call_count, 2)
+        Notification.objects.notify_user(self.user_2, 'dummy_2')
+        Notification.objects.update(viewed=True)
+        self.assertEqual(mock_invalidate_user_notification_cache.call_count, 2)
 
 
 class TestUserNotify(TestCase):
@@ -34,16 +34,16 @@ class TestUserNotify(TestCase):
     def setUpTestData(cls):
         cls.user = AuthUtils.create_user('magic_mike')
         AuthUtils.add_main_character(
-            cls.user, 
-            'Magic Mike', 
-            '1', 
-            corp_id='2', 
-            corp_name='Pole Riders', 
-            corp_ticker='PRIDE', 
-            alliance_id='3', 
+            cls.user,
+            'Magic Mike',
+            '1',
+            corp_id='2',
+            corp_name='Pole Riders',
+            corp_ticker='PRIDE',
+            alliance_id='3',
             alliance_name='RIDERS'
         )
-    
+
     def test_can_notify(self):
         title = 'dummy_title'
         message = 'dummy message'
@@ -57,14 +57,43 @@ class TestUserNotify(TestCase):
         self.assertEqual(obj.level, level)
 
     def test_use_message_as_title_if_missing(self):
-        title = 'dummy_title'        
+        title = 'dummy_title'
         Notification.objects.notify_user(self.user, title)
         self.assertEqual(Notification.objects.filter(user=self.user).count(), 1)
         obj = Notification.objects.first()
         self.assertEqual(obj.user, self.user)
         self.assertEqual(obj.title, title)
-        self.assertEqual(obj.message, title)       
-            
+        self.assertEqual(obj.message, title)
+
+    def test_should_use_default_level_when_not_specified(self):
+        # given
+        title = 'dummy_title'
+        message = 'dummy message'
+        # when
+        Notification.objects.notify_user(self.user, title, message)
+        # then
+        self.assertEqual(Notification.objects.filter(user=self.user).count(), 1)
+        obj = Notification.objects.first()
+        self.assertEqual(obj.user, self.user)
+        self.assertEqual(obj.title, title)
+        self.assertEqual(obj.message, message)
+        self.assertEqual(obj.level, Notification.Level.INFO)
+
+    def test_should_use_default_level_when_invalid_level_given(self):
+        # given
+        title = 'dummy_title'
+        message = 'dummy message'
+        level = "invalid"
+        # when
+        Notification.objects.notify_user(self.user, title, message, level)
+        # then
+        self.assertEqual(Notification.objects.filter(user=self.user).count(), 1)
+        obj = Notification.objects.first()
+        self.assertEqual(obj.user, self.user)
+        self.assertEqual(obj.title, title)
+        self.assertEqual(obj.message, message)
+        self.assertEqual(obj.level, Notification.Level.INFO)
+
     @override_settings(NOTIFICATIONS_MAX_PER_USER=3)
     def test_remove_when_too_many_notifications(self):
         Notification.objects.notify_user(self.user, 'dummy')
@@ -94,19 +123,19 @@ class TestMaxNotificationsPerUser(TestCase):
     def test_reset_to_default_if_not_defined(self):
         result = Notification.objects._max_notifications_per_user()
         expected = NOTIFICATIONS_MAX_PER_USER_DEFAULT
-        self.assertEquals(result, expected)
+        self.assertEqual(result, expected)
 
     @override_settings(NOTIFICATIONS_MAX_PER_USER='11')
     def test_reset_to_default_if_not_int(self):
         result = Notification.objects._max_notifications_per_user()
         expected = NOTIFICATIONS_MAX_PER_USER_DEFAULT
-        self.assertEquals(result, expected)
+        self.assertEqual(result, expected)
 
     @override_settings(NOTIFICATIONS_MAX_PER_USER=-1)
     def test_reset_to_default_if_lt_zero(self):
         result = Notification.objects._max_notifications_per_user()
         expected = NOTIFICATIONS_MAX_PER_USER_DEFAULT
-        self.assertEquals(result, expected)
+        self.assertEqual(result, expected)
 
 
 @patch('allianceauth.notifications.managers.cache')
@@ -116,16 +145,16 @@ class TestUnreadCount(TestCase):
     def setUpTestData(cls):
         cls.user_1 = AuthUtils.create_user('magic_mike')
         AuthUtils.add_main_character(
-            cls.user_1, 
-            'Magic Mike', 
-            '1', 
-            corp_id='2', 
-            corp_name='Pole Riders', 
-            corp_ticker='PRIDE', 
-            alliance_id='3', 
+            cls.user_1,
+            'Magic Mike',
+            '1',
+            corp_id='2',
+            corp_name='Pole Riders',
+            corp_ticker='PRIDE',
+            alliance_id='3',
             alliance_name='RIDERS'
         )
-        
+
         # test notifications for mike
         Notification.objects.all().delete()
         Notification.objects.create(
@@ -146,19 +175,19 @@ class TestUnreadCount(TestCase):
             level="INFO",
             title="Job 3 Failed",
             message="Because it was broken"
-        )        
+        )
 
         cls.user_2 = AuthUtils.create_user('teh_kid')
         AuthUtils.add_main_character(
-            cls.user_2, 
-            'The Kid', '2', 
-            corp_id='2', 
-            corp_name='Pole Riders', 
-            corp_ticker='PRIDE', 
-            alliance_id='3', 
+            cls.user_2,
+            'The Kid', '2',
+            corp_id='2',
+            corp_name='Pole Riders',
+            corp_ticker='PRIDE',
+            alliance_id='3',
             alliance_name='RIDERS'
         )
-        
+
         # Notifications for kid
         Notification.objects.create(
             user=cls.user_2,
@@ -166,7 +195,7 @@ class TestUnreadCount(TestCase):
             title="Job 6 Failed",
             message="Because it was broken"
         )
-    
+
     def test_update_cache_when_not_in_cache(self, mock_cache):
         mock_cache.get.return_value = None
 
@@ -174,9 +203,9 @@ class TestUnreadCount(TestCase):
         expected = 2
         self.assertEqual(result, expected)
         self.assertTrue(mock_cache.set.called)
-        args, kwargs = mock_cache.set.call_args        
+        args, kwargs = mock_cache.set.call_args
         self.assertEqual(
-            kwargs['key'], 
+            kwargs['key'],
             Notification.objects._user_notification_cache_key(self.user_1.pk)
         )
         self.assertEqual(kwargs['value'], expected)
@@ -190,17 +219,17 @@ class TestUnreadCount(TestCase):
 
     def test_return_error_code_when_user_not_found(self, mock_cache):
         mock_cache.get.return_value = None
-        invalid_user_id = max([user.pk for user in User.objects.all()]) + 1
+        invalid_user_id = max(user.pk for user in User.objects.all()) + 1
         result = Notification.objects.user_unread_count(invalid_user_id)
         expected = -1
         self.assertEqual(result, expected)
         self.assertFalse(mock_cache.set.called)
-    
+
     def test_can_invalidate_cache(self, mock_cache):
         Notification.objects.invalidate_user_notification_cache(self.user_1.pk)
         self.assertTrue(mock_cache.delete)
-        args, kwargs = mock_cache.delete.call_args        
+        args, kwargs = mock_cache.delete.call_args
         self.assertEqual(
-            kwargs['key'], 
+            kwargs['key'],
             Notification.objects._user_notification_cache_key(self.user_1.pk)
         )
