@@ -22,7 +22,7 @@ class DjangoBackend:
     @staticmethod
     def raise_or_lock(key, timeout):
         acquired = cache.add(key=key, value="lock", timeout=timeout)
-        if not acquired:            
+        if not acquired:
             raise AlreadyQueued(int(cache.ttl(key)))
 
     @staticmethod
@@ -33,13 +33,13 @@ class DjangoBackend:
 @shared_task(bind=True)
 def validate_services(self, pk):
     user = User.objects.get(pk=pk)
-    logger.debug('Ensuring user {} has permissions for active services'.format(user))
+    logger.debug(f'Ensuring user {user} has permissions for active services')
     # Iterate through services hooks and have them check the validity of the user
     for svc in ServicesHook.get_services():
         try:
             svc.validate_user(user)
         except:
-            logger.exception('Exception running validate_user for services module %s on user %s' % (svc, user))
+            logger.exception(f'Exception running validate_user for services module {svc} on user {user}')
 
 
 def disable_user(user):
@@ -47,4 +47,3 @@ def disable_user(user):
     for svc in ServicesHook.get_services():
         if svc.service_active_for_user(user):
             svc.delete_user(user)
-
